@@ -1,4 +1,4 @@
-# Copyright 2017 QuantRocket LLC - All Rights Reserved
+# Copyright 2017-2021 QuantRocket LLC - All Rights Reserved
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -64,6 +64,12 @@ class Moonshot(
     DB_TIMES : list of str (HH:MM:SS), optional
         for intraday databases, only retrieve these times
 
+    DB_DATA_FREQUENCY : str, optional
+        Only applicable when DB specifies a Zipline bundle. Whether to query minute or
+        daily data.  If omitted, defaults to minute data for minute bundles and to daily
+        data for daily bundles. This parameter only needs to be set to request daily data
+        from a minute bundle. Possible choices: daily, minute (or aliases d, m).
+
     SIDS : list of str, optional
         limit db query to these sids
 
@@ -146,10 +152,18 @@ class Moonshot(
         the price field to use for determining contract values for the purpose of
         applying commissions and constraining weights in backtests and calculating
         order quantities in trading. Defaults to the first available of Close, Open,
-        LastPriceClose, BidPriceClose, AskPriceClose, TimeSalesLastPriceClose,
-        TimeSalesFilteredLastPriceClose, LastPriceMean, BidPriceMean, AskPriceMean,
-        TimeSalesLastPriceMean, TimeSalesFilteredLastPriceMean, LastPriceOpen,
-        BidPriceOpen, AskPriceOpen, TimeSalesLastPriceOpen, TimeSalesFilteredLastPriceOpen.
+        MinuteCloseClose, SecondCloseClose, LastPriceClose, BidPriceClose, AskPriceClose,
+        TimeSalesLastPriceClose, TimeSalesFilteredLastPriceClose, LastPriceMean,
+        BidPriceMean, AskPriceMean, TimeSalesLastPriceMean, TimeSalesFilteredLastPriceMean,
+        MinuteOpenOpen, SecondOpenOpen, LastPriceOpen, BidPriceOpen, AskPriceOpen,
+        TimeSalesLastPriceOpen, TimeSalesFilteredLastPriceOpen.
+
+    ACCOUNT_BALANCE_FIELD : str or list of str, optional
+        the account field to use for calculating order quantities as a percentage of
+        account equity. Applies to trading only, not backtesting. Default is
+        NetLiquidation. If a list of fields is provided, the minimum value is used.
+        For example, ['NetLiquidation', 'PreviousEquity'] means to use the lesser of
+        NetLiquidation or PreviousEquity to determine order quantities.
 
     Examples
     --------
@@ -172,6 +186,7 @@ class Moonshot(
     DB = None
     DB_FIELDS = ["Open", "Close", "Volume"]
     DB_TIMES = None
+    DB_DATA_FREQUENCY = None
     SIDS = None
     UNIVERSES = None
     EXCLUDE_SIDS = None
@@ -190,6 +205,7 @@ class Moonshot(
     POSITIONS_CLOSED_DAILY = False
     ALLOW_REBALANCE = True
     CONTRACT_VALUE_REFERENCE_FIELD = None
+    ACCOUNT_BALANCE_FIELD = None
 
     def __init__(self):
         self.is_trade = False
@@ -1048,7 +1064,8 @@ class Moonshot(
             times=self.DB_TIMES,
             cont_fut=self.CONT_FUT,
             fields=self.DB_FIELDS,
-            timezone=self.TIMEZONE
+            timezone=self.TIMEZONE,
+            data_frequency=self.DB_DATA_FREQUENCY
         )
 
         if not self.TIMEZONE:
@@ -1218,7 +1235,11 @@ class Moonshot(
                     sids=self.BENCHMARK,
                     start_date=prices.index.get_level_values("Date").min(),
                     end_date=prices.index.get_level_values("Date").max(),
-                    fields="Close"
+                    fields="Close",
+                    # if this is a minute Zipline bundle, we want to query
+                    # daily bars; data_frequency is ignored if this is not
+                    # a Zipline bundle
+                    data_frequency="daily"
                 )
             except requests.HTTPError as e:
                 raise MoonshotError("error querying BENCHMARK_DB {0}: {1}".format(
@@ -1419,14 +1440,21 @@ class Moonshot(
             quote_currencies = self._securities_master.Symbol.astype(str).str.split(".").str[0]
             currencies = currencies.where(sec_types != "CASH", quote_currencies)
 
+        account_balance_fields = self.ACCOUNT_BALANCE_FIELD or "NetLiquidation"
+        if not isinstance(account_balance_fields, (list, tuple)):
+            account_balance_fields = [account_balance_fields]
+
         f = io.StringIO()
         download_account_balances(
             f,
             latest=True,
             accounts=list(allocations.index),
-            fields=["NetLiquidation"])
+            fields=account_balance_fields)
 
-        balances = pd.read_csv(f, index_col="Account")
+        balances = pd.read_csv(f)
+        # Cast account numbers to strings
+        balances["Account"] = balances.Account.astype(str)
+        balances = balances.set_index("Account")
 
         f = io.StringIO()
         download_exchange_rates(
@@ -1435,7 +1463,8 @@ class Moonshot(
             quote_currencies=list(currencies.unique()))
         exchange_rates = pd.read_csv(f)
 
-        nlvs = balances.NetLiquidation.reindex(allocations.index)
+        # Use the lesser field if multiple fields were given (see class docstring)
+        nlvs = balances[account_balance_fields].min(axis=1).reindex(allocations.index)
         # Out:
         # U12345 1000000
         # U55555  500000
@@ -1583,6 +1612,8 @@ class Moonshot(
 
         if positions:
             positions = pd.DataFrame(positions)
+            # Cast account numbers to strings
+            positions["Account"] = positions.Account.astype(str)
         else:
             positions = pd.DataFrame(columns=["Sid","Account","Quantity"])
 
@@ -1600,6 +1631,8 @@ class Moonshot(
         if f.getvalue():
             orders = json.load(f)
             orders = pd.DataFrame(orders)
+            # cast account numbers to strings
+            orders["Account"] = orders.Account.astype(str)
             orders.loc[orders.Action == "SELL", "Remaining"] = -orders.loc[orders.Action == "SELL"].Remaining
             orders = orders.groupby([orders.Sid, orders.Account]).Remaining.sum().reset_index()
         else:
@@ -1627,6 +1660,8 @@ class Moonshot(
                 'Open',
 
                 # realtime db candidate fields
+                'MinuteCloseClose',
+                'SecondCloseClose',
                 'LastPriceClose',
                 'BidPriceClose',
                 'AskPriceClose',
@@ -1637,6 +1672,8 @@ class Moonshot(
                 'AskPriceMean',
                 'TimeSalesLastPriceMean',
                 'TimeSalesFilteredLastPriceMean',
+                'MinuteOpenOpen',
+                'SecondOpenOpen',
                 'LastPriceOpen',
                 'BidPriceOpen',
                 'AskPriceOpen',
