@@ -1,4 +1,4 @@
-# Copyright 2019 QuantRocket LLC - All Rights Reserved
+# Copyright 2017-2021 QuantRocket LLC - All Rights Reserved
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -64,6 +64,12 @@ class MoonshotML(Moonshot):
     DB_TIMES : list of str (HH:MM:SS), optional
         for intraday databases, only retrieve these times
 
+    DB_DATA_FREQUENCY : str, optional
+        Only applicable when DB specifies a Zipline bundle. Whether to query minute or
+        daily data.  If omitted, defaults to minute data for minute bundles and to daily
+        data for daily bundles. This parameter only needs to be set to request daily data
+        from a minute bundle. Possible choices: daily, minute (or aliases d, m).
+
     SIDS : list of str, optional
         limit db query to these sids
 
@@ -142,6 +148,23 @@ class MoonshotML(Moonshot):
         this percentage. For example 0.5 means don't rebalance a position unless
         the position will change by +/-50%.
 
+    CONTRACT_VALUE_REFERENCE_FIELD : str, optional
+        the price field to use for determining contract values for the purpose of
+        applying commissions and constraining weights in backtests and calculating
+        order quantities in trading. Defaults to the first available of Close, Open,
+        MinuteCloseClose, SecondCloseClose, LastPriceClose, BidPriceClose, AskPriceClose,
+        TimeSalesLastPriceClose, TimeSalesFilteredLastPriceClose, LastPriceMean,
+        BidPriceMean, AskPriceMean, TimeSalesLastPriceMean, TimeSalesFilteredLastPriceMean,
+        MinuteOpenOpen, SecondOpenOpen, LastPriceOpen, BidPriceOpen, AskPriceOpen,
+        TimeSalesLastPriceOpen, TimeSalesFilteredLastPriceOpen.
+
+    ACCOUNT_BALANCE_FIELD : str or list of str, optional
+        the account field to use for calculating order quantities as a percentage of
+        account equity. Applies to trading only, not backtesting. Default is
+        NetLiquidation. If a list of fields is provided, the minimum value is used.
+        For example, ['NetLiquidation', 'PreviousEquity'] means to use the lesser of
+        NetLiquidation or PreviousEquity to determine order quantities.
+
     Examples
     --------
     Example of a minimal strategy that runs on a history db called "usa-stk-1d", trains
