@@ -46,7 +46,7 @@ class AllowRebalanceTestCase(unittest.TestCase):
 
         def mock_get_prices(*args, **kwargs):
 
-            dt_idx = pd.date_range(end=pd.Timestamp.today(tz="America/New_York"), periods=3, normalize=True)
+            dt_idx = pd.date_range(end=pd.Timestamp.today(tz="America/New_York"), periods=3, normalize=True).tz_localize(None)
             fields = ["Close"]
             idx = pd.MultiIndex.from_product([fields, dt_idx], names=["Field", "Date"])
 
@@ -187,7 +187,7 @@ class AllowRebalanceTestCase(unittest.TestCase):
 
         def mock_get_prices(*args, **kwargs):
 
-            dt_idx = pd.date_range(end=pd.Timestamp.today(tz="America/New_York"), periods=3, normalize=True)
+            dt_idx = pd.date_range(end=pd.Timestamp.today(tz="America/New_York"), periods=3, normalize=True).tz_localize(None)
             fields = ["Close"]
             idx = pd.MultiIndex.from_product([fields, dt_idx], names=["Field", "Date"])
 
@@ -352,7 +352,7 @@ class AllowRebalanceTestCase(unittest.TestCase):
 
         def mock_get_prices(*args, **kwargs):
 
-            dt_idx = pd.date_range(end=pd.Timestamp.today(tz="America/New_York"), periods=3, normalize=True)
+            dt_idx = pd.date_range(end=pd.Timestamp.today(tz="America/New_York"), periods=3, normalize=True).tz_localize(None)
             fields = ["Close"]
             idx = pd.MultiIndex.from_product([fields, dt_idx], names=["Field", "Date"])
 
@@ -534,7 +534,7 @@ class AllowRebalanceTestCase(unittest.TestCase):
 
         def mock_get_prices(*args, **kwargs):
 
-            dt_idx = pd.date_range(end=pd.Timestamp.today(tz="America/New_York"), periods=3, normalize=True)
+            dt_idx = pd.date_range(end=pd.Timestamp.today(tz="America/New_York"), periods=3, normalize=True).tz_localize(None)
             fields = ["Close"]
             idx = pd.MultiIndex.from_product([fields, dt_idx], names=["Field", "Date"])
 
