@@ -1319,7 +1319,7 @@ class LimitPositionSizesTradeTestCase(unittest.TestCase):
 
         def mock_get_prices(*args, **kwargs):
 
-            dt_idx = pd.date_range(end=pd.Timestamp.today(tz="America/New_York"), periods=3, normalize=True)
+            dt_idx = pd.date_range(end=pd.Timestamp.today(tz="America/New_York"), periods=3, normalize=True).tz_localize(None)
             fields = ["Open"]
             idx = pd.MultiIndex.from_product([fields, dt_idx], names=["Field", "Date"])
 
@@ -1469,7 +1469,7 @@ class LimitPositionSizesTradeTestCase(unittest.TestCase):
 
         def mock_get_prices(*args, **kwargs):
 
-            dt_idx = pd.date_range(end=pd.Timestamp.today(tz="America/New_York"), periods=3, normalize=True)
+            dt_idx = pd.date_range(end=pd.Timestamp.today(tz="America/New_York"), periods=3, normalize=True).tz_localize(None)
             fields = ["Open"]
             idx = pd.MultiIndex.from_product([fields, dt_idx], names=["Field", "Date"])
 
@@ -1617,7 +1617,7 @@ class LimitPositionSizesTradeTestCase(unittest.TestCase):
 
         def mock_get_prices(*args, **kwargs):
 
-            dt_idx = pd.date_range(end=pd.Timestamp.today(tz="America/New_York"), periods=3, normalize=True)
+            dt_idx = pd.date_range(end=pd.Timestamp.today(tz="America/New_York"), periods=3, normalize=True).tz_localize(None)
             fields = ["Open"]
             idx = pd.MultiIndex.from_product([fields, dt_idx], names=["Field", "Date"])
 
@@ -1771,7 +1771,7 @@ class LimitPositionSizesTradeTestCase(unittest.TestCase):
 
         def mock_get_prices(*args, **kwargs):
 
-            dt_idx = pd.date_range(end=pd.Timestamp.today(tz="America/New_York"), periods=3, normalize=True)
+            dt_idx = pd.date_range(end=pd.Timestamp.today(tz="America/New_York"), periods=3, normalize=True).tz_localize(None)
             fields = ["Open"]
             idx = pd.MultiIndex.from_product([fields, dt_idx], names=["Field", "Date"])
 
@@ -1946,7 +1946,7 @@ class LimitPositionSizesTradeTestCase(unittest.TestCase):
 
         def mock_get_prices(*args, **kwargs):
 
-            dt_idx = pd.date_range(end=pd.Timestamp.today(tz="America/New_York"), periods=3, normalize=True)
+            dt_idx = pd.date_range(end=pd.Timestamp.today(tz="America/New_York"), periods=3, normalize=True).tz_localize(None)
             fields = ["Open"]
             idx = pd.MultiIndex.from_product([fields, dt_idx], names=["Field", "Date"])
 
@@ -2098,7 +2098,7 @@ class LimitPositionSizesTradeTestCase(unittest.TestCase):
 
         def mock_get_prices(*args, **kwargs):
 
-            dt_idx = pd.date_range(end=pd.Timestamp.today(tz="America/New_York"), periods=3, normalize=True)
+            dt_idx = pd.date_range(end=pd.Timestamp.today(tz="America/New_York"), periods=3, normalize=True).tz_localize(None)
             fields = ["Close"]
             times = ["09:30:00", "15:30:00"]
             idx = pd.MultiIndex.from_product(
