@@ -48,6 +48,7 @@ class GetPricesTestCase(unittest.TestCase):
             DB = 'test-db'
             DB_FIELDS = ["Volume", "Wap", "Close"]
             DB_TIMES = ["00:00:00"]
+            DB_DATA_FREQUENCY = "daily"
             UNIVERSES = "us-stk"
             SIDS = ["FI12345","FI23456"]
             EXCLUDE_SIDS = "FI34567"
@@ -152,6 +153,7 @@ class GetPricesTestCase(unittest.TestCase):
         self.assertEqual(kwargs["exclude_sids"], "FI34567")
         self.assertEqual(kwargs["fields"], ['Volume', 'Wap', 'Close'])
         self.assertEqual(kwargs["times"], ["00:00:00"])
+        self.assertEqual(kwargs["data_frequency"], "daily")
         self.assertFalse(kwargs["cont_fut"])
         self.assertIsNone(kwargs["timezone"])
         self.assertTrue(kwargs["infer_timezone"])
@@ -462,7 +464,7 @@ class GetPricesTestCase(unittest.TestCase):
         get_prices_call = mock_get_prices.mock_calls[0]
         _, args, kwargs = get_prices_call
         self.assertListEqual(kwargs["codes"], ["test-db"])
-        self.assertIn(kwargs["start_date"], ("2017-08-04", "2017-08-05")) # 100 + 60ish trading days before requested start_date
+        self.assertIn(kwargs["start_date"], ("2017-08-04", "2017-08-05", "2017-08-06")) # 100 + 60ish trading days before requested start_date
         self.assertEqual(kwargs["end_date"], "2018-05-04")
         self.assertEqual(kwargs["fields"], ['Open', 'Close', 'Volume'])
         self.assertIsNone(kwargs["timezone"])
